@@ -1,5 +1,5 @@
 /* GDA library
- * Copyright (C) 2006 The GNOME Foundation.
+ * Copyright (C) 2006 - 2008 The GNOME Foundation.
  *
  * AUTHORS:
  *      Vivien Malerba <malerba@gnome-db.org>
@@ -25,15 +25,16 @@
 #include <string.h>
 #include <glib/gi18n-lib.h>
 #include <libgda/gda-enums.h>
-#include <libgda/gda-parameter.h>
 #include <libgda/gda-data-model.h>
+#include <libgda/gda-data-model-extra.h>
 #include <libgda/gda-data-model-iter.h>
 #include <libgda/gda-row.h>
+#include <libgda/gda-holder.h>
 
 
 struct _GdaDataAccessWrapperPrivate {
 	GdaDataModel     *model;
-	guint             model_access_flags;
+	GdaDataModelAccessFlags model_access_flags;
 
 	GdaDataModelIter *iter;    /* iterator on @model, NULL if @model already is random access */
 	gint              iter_row;/* current row of @iter, starting at 0 when created */
@@ -71,16 +72,15 @@ static void                 gda_data_access_wrapper_data_model_init (GdaDataMode
 static gint                 gda_data_access_wrapper_get_n_rows      (GdaDataModel *model);
 static gint                 gda_data_access_wrapper_get_n_columns   (GdaDataModel *model);
 static GdaColumn           *gda_data_access_wrapper_describe_column (GdaDataModel *model, gint col);
-static guint                gda_data_access_wrapper_get_access_flags(GdaDataModel *model);
+static GdaDataModelAccessFlags gda_data_access_wrapper_get_access_flags(GdaDataModel *model);
 static const GValue      *gda_data_access_wrapper_get_value_at    (GdaDataModel *model, gint col, gint row);
-static guint                gda_data_access_wrapper_get_attributes_at (GdaDataModel *model, gint col, gint row);
-#ifdef GDA_DEBUG
-static void gda_data_access_wrapper_dump (GdaDataAccessWrapper *model, guint offset);
-#endif
+static GdaValueAttribute    gda_data_access_wrapper_get_attributes_at (GdaDataModel *model, gint col, gint row);
 
 static void iter_row_changed_cb (GdaDataModelIter *iter, gint row, GdaDataAccessWrapper *model);
 static void iter_end_of_data_cb (GdaDataModelIter *iter, GdaDataAccessWrapper *model);
 
+static GdaRow *create_new_row (GdaDataAccessWrapper *model);
+
 static GObjectClass *parent_class = NULL;
 
 /**
@@ -93,7 +93,7 @@ gda_data_access_wrapper_get_type (void)
 {
 	static GType type = 0;
 
-	if (!type) {
+	if (G_UNLIKELY (type == 0)) {
 		static const GTypeInfo info = {
 			sizeof (GdaDataAccessWrapperClass),
 			(GBaseInitFunc) NULL,
@@ -112,7 +112,7 @@ gda_data_access_wrapper_get_type (void)
 			NULL
 		};
 
-		type = g_type_register_static (GDA_TYPE_OBJECT, "GdaDataAccessWrapper", &info, 0);
+		type = g_type_register_static (G_TYPE_OBJECT, "GdaDataAccessWrapper", &info, 0);
 		g_type_add_interface_static (type, GDA_TYPE_DATA_MODEL, &data_model_info);
 	}
 	return type;
@@ -129,19 +129,14 @@ gda_data_access_wrapper_class_init (GdaDataAccessWrapperClass *klass)
 	object_class->set_property = gda_data_access_wrapper_set_property;
         object_class->get_property = gda_data_access_wrapper_get_property;
 	g_object_class_install_property (object_class, PROP_MODEL,
-                                         g_param_spec_pointer ("model", "Data model being worked on", NULL,
+                                         g_param_spec_object ("model", "Data model being worked on", NULL,
+                                                              GDA_TYPE_DATA_MODEL,
 							      G_PARAM_READABLE | G_PARAM_WRITABLE |
 							      G_PARAM_CONSTRUCT_ONLY));
 
 	/* virtual functions */
 	object_class->dispose = gda_data_access_wrapper_dispose;
 	object_class->finalize = gda_data_access_wrapper_finalize;
-#ifdef GDA_DEBUG
-        GDA_OBJECT_CLASS (klass)->dump = (void (*)(GdaObject *, guint)) gda_data_access_wrapper_dump;
-#endif
-
-	/* class attributes */
-	GDA_OBJECT_CLASS (klass)->id_unique_enforced = FALSE;
 }
 
 static void
@@ -182,18 +177,21 @@ gda_data_access_wrapper_init (GdaDataAccessWrapper *model, GdaDataAccessWrapperC
 }
 
 static void
-data_model_destroyed_cb (GdaDataModel *mod, GdaDataAccessWrapper *model)
+model_row_inserted_cb (GdaDataModel *mod, gint row, GdaDataAccessWrapper *model)
 {
-	g_assert (model->priv->model == mod);
-	g_signal_handlers_disconnect_by_func (mod, G_CALLBACK (data_model_destroyed_cb), model);
+	gda_data_model_row_inserted ((GdaDataModel*) model, row);
+}
 
-	if (model->priv->rows) {
-		g_hash_table_destroy (model->priv->rows);
-		model->priv->rows = NULL;
-	}
-	model->priv->model = NULL;
+static void
+model_row_updated_cb (GdaDataModel *mod, gint row, GdaDataAccessWrapper *model)
+{
+	gda_data_model_row_updated ((GdaDataModel*) model, row);
+}
 
-	g_object_unref (mod);
+static void
+model_row_removed_cb (GdaDataModel *mod, gint row, GdaDataAccessWrapper *model)
+{
+	gda_data_model_row_removed ((GdaDataModel*) model, row);
 }
 
 static void
@@ -221,8 +219,22 @@ gda_data_access_wrapper_dispose (GObject *object)
 		}
 
 		/* random access model free */
-		if (model->priv->model) 
-			data_model_destroyed_cb (model->priv->model, model);
+		if (model->priv->model) {
+			if (model->priv->rows) {
+				g_hash_table_destroy (model->priv->rows);
+				model->priv->rows = NULL;
+			}
+			else {
+				g_signal_handlers_disconnect_by_func (G_OBJECT (model->priv->model),
+								      G_CALLBACK (model_row_inserted_cb), model);
+				g_signal_handlers_disconnect_by_func (G_OBJECT (model->priv->model),
+								      G_CALLBACK (model_row_updated_cb), model);
+				g_signal_handlers_disconnect_by_func (G_OBJECT (model->priv->model),
+								      G_CALLBACK (model_row_removed_cb), model);
+			}
+			g_object_unref (model->priv->model);
+			model->priv->model = NULL;
+		}
 	}
 
 	/* chain to parent class */
@@ -246,12 +258,11 @@ gda_data_access_wrapper_finalize (GObject *object)
 	parent_class->finalize (object);
 }
 
-
 static void
 gda_data_access_wrapper_set_property (GObject *object,
-					guint param_id,
-					const GValue *value,
-					GParamSpec *pspec)
+				      guint param_id,
+				      const GValue *value,
+				      GParamSpec *pspec)
 {
 	GdaDataAccessWrapper *model;
 
@@ -259,9 +270,7 @@ gda_data_access_wrapper_set_property (GObject *object,
 	if (model->priv) {
 		switch (param_id) {
 		case PROP_MODEL: {
-			GdaDataModel *mod;
-
-			mod = g_value_get_pointer (value);
+			GdaDataModel *mod = g_value_get_object(value);
 			if (mod) {
 				g_return_if_fail (GDA_IS_DATA_MODEL (mod));
 				model->priv->model_access_flags = gda_data_model_get_access_flags (mod);
@@ -276,10 +285,20 @@ gda_data_access_wrapper_set_property (GObject *object,
 					model->priv->rows = g_hash_table_new_full (g_direct_hash, g_direct_equal,
 										   NULL, (GDestroyNotify) g_object_unref);
 				}
+				else {
+					g_signal_connect (G_OBJECT (mod), "row_inserted",
+							  G_CALLBACK (model_row_inserted_cb), model);
+					g_signal_connect (G_OBJECT (mod), "row_updated",
+							  G_CALLBACK (model_row_updated_cb), model);
+					g_signal_connect (G_OBJECT (mod), "row_removed",
+							  G_CALLBACK (model_row_removed_cb), model);
+				}
+  
+                                if (model->priv->model)
+					g_object_unref (model->priv->model);
+
 				model->priv->model = mod;
 				g_object_ref (mod);
-				gda_object_connect_destroy (GDA_OBJECT (mod), 
-							    G_CALLBACK (data_model_destroyed_cb), model);
 				model->priv->nb_cols = gda_data_model_get_n_columns (mod);
 			}
 			break;
@@ -303,7 +322,7 @@ gda_data_access_wrapper_get_property (GObject *object,
 	if (model->priv) {
 		switch (param_id) {
 		case PROP_MODEL:
-			g_value_set_pointer (value, model->priv->model);
+			g_value_set_object (value, G_OBJECT (model->priv->model));
 			break;
 		default:
 			g_assert_not_reached ();
@@ -329,7 +348,6 @@ gda_data_access_wrapper_new (GdaDataModel *model)
 	g_return_val_if_fail (GDA_IS_DATA_MODEL (model), NULL);
 	
 	retmodel = g_object_new (GDA_TYPE_DATA_ACCESS_WRAPPER,
-				 "dict", gda_object_get_dict (GDA_OBJECT (model)),
 				 "model", model, NULL);
 			      
 	return GDA_DATA_MODEL (retmodel);
@@ -358,31 +376,6 @@ gda_data_access_wrapper_row_exists (GdaDataAccessWrapper *wrapper, gint row)
 		return FALSE;
 }
 
-#ifdef GDA_DEBUG
-static void
-gda_data_access_wrapper_dump (GdaDataAccessWrapper *model, guint offset)
-{
-	gchar *str;
-
-	str = g_new0 (gchar, offset+1);
-	memset (str, ' ', offset);
-	if (model->priv) {
-		gint i;
-		if (model->priv->rows) {
-			for (i = 0; i <= model->priv->last_row; i++) {
-				GdaRow *row = g_hash_table_lookup (model->priv->rows, GINT_TO_POINTER (i));
-				g_print ("%srow %d: %s\n", str, i, row ? "SET" : "---");
-			}
-		}
-		if (model->priv->model) 
-			gda_data_model_dump (model->priv->model, stdout);
-	}
-	else
-		g_print ("%s" D_COL_ERR "Using finalized object %p" D_COL_NOR, str, model);
-	g_free (str);
-}
-#endif
-
 /*
  * GdaDataModel interface implementation
  */
@@ -398,6 +391,11 @@ gda_data_access_wrapper_get_n_rows (GdaDataModel *model)
 		/* imodel->priv->mode is a random access model, use it */
 		return gda_data_model_get_n_rows (imodel->priv->model);
 	else {
+		/* go at the end */
+		while (!imodel->priv->end_of_data) {
+			if (! gda_data_model_iter_move_next (imodel->priv->iter)) 
+				break;
+		}
 		if (imodel->priv->end_of_data)
 			return imodel->priv->last_row +1;
 		else
@@ -433,7 +431,7 @@ gda_data_access_wrapper_describe_column (GdaDataModel *model, gint col)
 		return NULL;
 }
 
-static guint
+static GdaDataModelAccessFlags
 gda_data_access_wrapper_get_access_flags (GdaDataModel *model)
 {
 	GdaDataAccessWrapper *imodel;
@@ -453,11 +451,11 @@ create_new_row (GdaDataAccessWrapper *model)
 
 	row = gda_row_new ((GdaDataModel *) model, model->priv->nb_cols);
 	for (i = 0; i < model->priv->nb_cols; i++) {
-		GdaParameter *param;
+		GdaHolder *holder;
 
-		param = gda_data_model_iter_get_param_for_column (model->priv->iter, i);
-		if (param)
-			gda_row_set_value (row, i, gda_parameter_get_value (param));
+		holder = gda_data_model_iter_get_holder_for_field (model->priv->iter, i);
+		if (holder)
+			gda_row_set_value (row, i, gda_holder_get_value (holder));
 	}
 
 	g_hash_table_insert (model->priv->rows, GINT_TO_POINTER (model->priv->iter_row), row);
@@ -495,7 +493,7 @@ gda_data_access_wrapper_get_value_at (GdaDataModel *model, gint col, gint row)
 			g_assert (imodel->priv->iter);
 			if (imodel->priv->iter_row < 0) {
 				if (gda_data_model_iter_move_next (imodel->priv->iter)) {
-					gda_row = create_new_row (imodel);
+					gda_row = g_hash_table_lookup (imodel->priv->rows, GINT_TO_POINTER (row));
 					if (row == imodel->priv->iter_row)
 						return gda_row_get_value (gda_row, col);
 				}
@@ -508,17 +506,17 @@ gda_data_access_wrapper_get_value_at (GdaDataModel *model, gint col, gint row)
 				if (row > imodel->priv->iter_row) {
 					/* need to move forward */
 					while ((imodel->priv->iter_row < row) && 
-					       gda_data_model_iter_move_next (imodel->priv->iter)) ;
+					       gda_data_model_iter_move_next (imodel->priv->iter));
 				}
 				else {
 					/* need to move backwards */
+					g_assert (imodel->priv->model_access_flags & GDA_DATA_MODEL_ACCESS_CURSOR_BACKWARD);
 					while ((imodel->priv->iter_row > row) && 
 					       gda_data_model_iter_move_prev (imodel->priv->iter)) ;
 				}
 			}
 
-			if (row == imodel->priv->iter_row) 
-				gda_row = create_new_row (imodel);
+			gda_row = g_hash_table_lookup (imodel->priv->rows, GINT_TO_POINTER (row));
 
 			if (gda_row)
 				return gda_row_get_value (gda_row, col);
@@ -560,18 +558,19 @@ iter_end_of_data_cb (GdaDataModelIter *iter, GdaDataAccessWrapper *model)
 	model->priv->end_of_data = TRUE;
 }
 
-static guint
+static GdaValueAttribute
 gda_data_access_wrapper_get_attributes_at (GdaDataModel *model, gint col, gint row)
 {
-	guint flags = 0;
+	GdaValueAttribute flags = 0;
 	GdaDataAccessWrapper *imodel;
 
 	g_return_val_if_fail (GDA_IS_DATA_ACCESS_WRAPPER (model), 0);
 	imodel = (GdaDataAccessWrapper *) model;
 	g_return_val_if_fail (imodel->priv, 0);
-	
-	flags = GDA_VALUE_ATTR_NO_MODIF;
-	TO_IMPLEMENT;
+
+	if (!imodel->priv->rows)
+		flags = gda_data_model_get_attributes_at (imodel->priv->model, col, row);
+	flags |= GDA_VALUE_ATTR_NO_MODIF;
 	
 	return flags;
 }
