@@ -56,10 +56,10 @@
 /* VOID:OBJECT,OBJECT (gda-marshal.list:28) */
 void
 gda_marshal_VOID__OBJECT_OBJECT (GClosure     *closure,
-                                 GValue       *return_value G_GNUC_UNUSED,
+                                 GValue       *return_value,
                                  guint         n_param_values,
                                  const GValue *param_values,
-                                 gpointer      invocation_hint G_GNUC_UNUSED,
+                                 gpointer      invocation_hint,
                                  gpointer      marshal_data)
 {
   typedef void (*GMarshalFunc_VOID__OBJECT_OBJECT) (gpointer     data1,
@@ -93,10 +93,10 @@ gda_marshal_VOID__OBJECT_OBJECT (GClosure     *closure,
 /* VOID:OBJECT,ENUM,OBJECT (gda-marshal.list:29) */
 void
 gda_marshal_VOID__OBJECT_ENUM_OBJECT (GClosure     *closure,
-                                      GValue       *return_value G_GNUC_UNUSED,
+                                      GValue       *return_value,
                                       guint         n_param_values,
                                       const GValue *param_values,
-                                      gpointer      invocation_hint G_GNUC_UNUSED,
+                                      gpointer      invocation_hint,
                                       gpointer      marshal_data)
 {
   typedef void (*GMarshalFunc_VOID__OBJECT_ENUM_OBJECT) (gpointer     data1,
@@ -132,10 +132,10 @@ gda_marshal_VOID__OBJECT_ENUM_OBJECT (GClosure     *closure,
 /* VOID:OBJECT,UINT (gda-marshal.list:30) */
 void
 gda_marshal_VOID__OBJECT_UINT (GClosure     *closure,
-                               GValue       *return_value G_GNUC_UNUSED,
+                               GValue       *return_value,
                                guint         n_param_values,
                                const GValue *param_values,
-                               gpointer      invocation_hint G_GNUC_UNUSED,
+                               gpointer      invocation_hint,
                                gpointer      marshal_data)
 {
   typedef void (*GMarshalFunc_VOID__OBJECT_UINT) (gpointer     data1,
@@ -169,10 +169,10 @@ gda_marshal_VOID__OBJECT_UINT (GClosure     *closure,
 /* VOID:OBJECT,UINT,UINT (gda-marshal.list:31) */
 void
 gda_marshal_VOID__OBJECT_UINT_UINT (GClosure     *closure,
-                                    GValue       *return_value G_GNUC_UNUSED,
+                                    GValue       *return_value,
                                     guint         n_param_values,
                                     const GValue *param_values,
-                                    gpointer      invocation_hint G_GNUC_UNUSED,
+                                    gpointer      invocation_hint,
                                     gpointer      marshal_data)
 {
   typedef void (*GMarshalFunc_VOID__OBJECT_UINT_UINT) (gpointer     data1,
@@ -205,13 +205,50 @@ gda_marshal_VOID__OBJECT_UINT_UINT (GClosure     *closure,
             data2);
 }
 
-/* VOID:STRING,UINT,UINT (gda-marshal.list:32) */
+/* VOID:OBJECT,BOOLEAN (gda-marshal.list:32) */
+void
+gda_marshal_VOID__OBJECT_BOOLEAN (GClosure     *closure,
+                                  GValue       *return_value,
+                                  guint         n_param_values,
+                                  const GValue *param_values,
+                                  gpointer      invocation_hint,
+                                  gpointer      marshal_data)
+{
+  typedef void (*GMarshalFunc_VOID__OBJECT_BOOLEAN) (gpointer     data1,
+                                                     gpointer     arg_1,
+                                                     gboolean     arg_2,
+                                                     gpointer     data2);
+  register GMarshalFunc_VOID__OBJECT_BOOLEAN callback;
+  register GCClosure *cc = (GCClosure*) closure;
+  register gpointer data1, data2;
+
+  g_return_if_fail (n_param_values == 3);
+
+  if (G_CCLOSURE_SWAP_DATA (closure))
+    {
+      data1 = closure->data;
+      data2 = g_value_peek_pointer (param_values + 0);
+    }
+  else
+    {
+      data1 = g_value_peek_pointer (param_values + 0);
+      data2 = closure->data;
+    }
+  callback = (GMarshalFunc_VOID__OBJECT_BOOLEAN) (marshal_data ? marshal_data : cc->callback);
+
+  callback (data1,
+            g_marshal_value_peek_object (param_values + 1),
+            g_marshal_value_peek_boolean (param_values + 2),
+            data2);
+}
+
+/* VOID:STRING,UINT,UINT (gda-marshal.list:33) */
 void
 gda_marshal_VOID__STRING_UINT_UINT (GClosure     *closure,
-                                    GValue       *return_value G_GNUC_UNUSED,
+                                    GValue       *return_value,
                                     guint         n_param_values,
                                     const GValue *param_values,
-                                    gpointer      invocation_hint G_GNUC_UNUSED,
+                                    gpointer      invocation_hint,
                                     gpointer      marshal_data)
 {
   typedef void (*GMarshalFunc_VOID__STRING_UINT_UINT) (gpointer     data1,
@@ -244,13 +281,13 @@ gda_marshal_VOID__STRING_UINT_UINT (GClosure     *closure,
             data2);
 }
 
-/* VOID:ENUM,OBJECT (gda-marshal.list:33) */
+/* VOID:ENUM,OBJECT (gda-marshal.list:34) */
 void
 gda_marshal_VOID__ENUM_OBJECT (GClosure     *closure,
-                               GValue       *return_value G_GNUC_UNUSED,
+                               GValue       *return_value,
                                guint         n_param_values,
                                const GValue *param_values,
-                               gpointer      invocation_hint G_GNUC_UNUSED,
+                               gpointer      invocation_hint,
                                gpointer      marshal_data)
 {
   typedef void (*GMarshalFunc_VOID__ENUM_OBJECT) (gpointer     data1,
@@ -281,15 +318,15 @@ gda_marshal_VOID__ENUM_OBJECT (GClosure     *closure,
             data2);
 }
 
-/* VOID:UINT,POINTER (gda-marshal.list:34) */
+/* VOID:UINT,POINTER (gda-marshal.list:35) */
 
-/* VOID:INT,INT (gda-marshal.list:35) */
+/* VOID:INT,INT (gda-marshal.list:36) */
 void
 gda_marshal_VOID__INT_INT (GClosure     *closure,
-                           GValue       *return_value G_GNUC_UNUSED,
+                           GValue       *return_value,
                            guint         n_param_values,
                            const GValue *param_values,
-                           gpointer      invocation_hint G_GNUC_UNUSED,
+                           gpointer      invocation_hint,
                            gpointer      marshal_data)
 {
   typedef void (*GMarshalFunc_VOID__INT_INT) (gpointer     data1,
@@ -320,13 +357,13 @@ gda_marshal_VOID__INT_INT (GClosure     *closure,
             data2);
 }
 
-/* VOID:INT,BOXED,BOXED (gda-marshal.list:36) */
+/* VOID:INT,BOXED,BOXED (gda-marshal.list:37) */
 void
 gda_marshal_VOID__INT_BOXED_BOXED (GClosure     *closure,
-                                   GValue       *return_value G_GNUC_UNUSED,
+                                   GValue       *return_value,
                                    guint         n_param_values,
                                    const GValue *param_values,
-                                   gpointer      invocation_hint G_GNUC_UNUSED,
+                                   gpointer      invocation_hint,
                                    gpointer      marshal_data)
 {
   typedef void (*GMarshalFunc_VOID__INT_BOXED_BOXED) (gpointer     data1,
@@ -359,13 +396,13 @@ gda_marshal_VOID__INT_BOXED_BOXED (GClosure     *closure,
             data2);
 }
 
-/* VOID:INT,BOOLEAN (gda-marshal.list:37) */
+/* VOID:INT,BOOLEAN (gda-marshal.list:38) */
 void
 gda_marshal_VOID__INT_BOOLEAN (GClosure     *closure,
-                               GValue       *return_value G_GNUC_UNUSED,
+                               GValue       *return_value,
                                guint         n_param_values,
                                const GValue *param_values,
-                               gpointer      invocation_hint G_GNUC_UNUSED,
+                               gpointer      invocation_hint,
                                gpointer      marshal_data)
 {
   typedef void (*GMarshalFunc_VOID__INT_BOOLEAN) (gpointer     data1,
@@ -396,13 +433,13 @@ gda_marshal_VOID__INT_BOOLEAN (GClosure     *closure,
             data2);
 }
 
-/* VOID:STRING,INT (gda-marshal.list:38) */
+/* VOID:STRING,INT (gda-marshal.list:39) */
 void
 gda_marshal_VOID__STRING_INT (GClosure     *closure,
-                              GValue       *return_value G_GNUC_UNUSED,
+                              GValue       *return_value,
                               guint         n_param_values,
                               const GValue *param_values,
-                              gpointer      invocation_hint G_GNUC_UNUSED,
+                              gpointer      invocation_hint,
                               gpointer      marshal_data)
 {
   typedef void (*GMarshalFunc_VOID__STRING_INT) (gpointer     data1,
@@ -433,13 +470,50 @@ gda_marshal_VOID__STRING_INT (GClosure     *closure,
             data2);
 }
 
-/* BOOLEAN:INT (gda-marshal.list:39) */
+/* VOID:ENUM,POINTER (gda-marshal.list:40) */
+void
+gda_marshal_VOID__ENUM_POINTER (GClosure     *closure,
+                                GValue       *return_value,
+                                guint         n_param_values,
+                                const GValue *param_values,
+                                gpointer      invocation_hint,
+                                gpointer      marshal_data)
+{
+  typedef void (*GMarshalFunc_VOID__ENUM_POINTER) (gpointer     data1,
+                                                   gint         arg_1,
+                                                   gpointer     arg_2,
+                                                   gpointer     data2);
+  register GMarshalFunc_VOID__ENUM_POINTER callback;
+  register GCClosure *cc = (GCClosure*) closure;
+  register gpointer data1, data2;
+
+  g_return_if_fail (n_param_values == 3);
+
+  if (G_CCLOSURE_SWAP_DATA (closure))
+    {
+      data1 = closure->data;
+      data2 = g_value_peek_pointer (param_values + 0);
+    }
+  else
+    {
+      data1 = g_value_peek_pointer (param_values + 0);
+      data2 = closure->data;
+    }
+  callback = (GMarshalFunc_VOID__ENUM_POINTER) (marshal_data ? marshal_data : cc->callback);
+
+  callback (data1,
+            g_marshal_value_peek_enum (param_values + 1),
+            g_marshal_value_peek_pointer (param_values + 2),
+            data2);
+}
+
+/* BOOLEAN:INT (gda-marshal.list:41) */
 void
 gda_marshal_BOOLEAN__INT (GClosure     *closure,
-                          GValue       *return_value G_GNUC_UNUSED,
+                          GValue       *return_value,
                           guint         n_param_values,
                           const GValue *param_values,
-                          gpointer      invocation_hint G_GNUC_UNUSED,
+                          gpointer      invocation_hint,
                           gpointer      marshal_data)
 {
   typedef gboolean (*GMarshalFunc_BOOLEAN__INT) (gpointer     data1,
@@ -472,13 +546,13 @@ gda_marshal_BOOLEAN__INT (GClosure     *closure,
   g_value_set_boolean (return_value, v_return);
 }
 
-/* BOOLEAN:INT,INT (gda-marshal.list:40) */
+/* BOOLEAN:INT,INT (gda-marshal.list:42) */
 void
 gda_marshal_BOOLEAN__INT_INT (GClosure     *closure,
-                              GValue       *return_value G_GNUC_UNUSED,
+                              GValue       *return_value,
                               guint         n_param_values,
                               const GValue *param_values,
-                              gpointer      invocation_hint G_GNUC_UNUSED,
+                              gpointer      invocation_hint,
                               gpointer      marshal_data)
 {
   typedef gboolean (*GMarshalFunc_BOOLEAN__INT_INT) (gpointer     data1,
@@ -513,3 +587,42 @@ gda_marshal_BOOLEAN__INT_INT (GClosure     *closure,
   g_value_set_boolean (return_value, v_return);
 }
 
+/* POINTER:POINTER (gda-marshal.list:43) */
+void
+gda_marshal_POINTER__POINTER (GClosure     *closure,
+                              GValue       *return_value,
+                              guint         n_param_values,
+                              const GValue *param_values,
+                              gpointer      invocation_hint,
+                              gpointer      marshal_data)
+{
+  typedef gpointer (*GMarshalFunc_POINTER__POINTER) (gpointer     data1,
+                                                     gpointer     arg_1,
+                                                     gpointer     data2);
+  register GMarshalFunc_POINTER__POINTER callback;
+  register GCClosure *cc = (GCClosure*) closure;
+  register gpointer data1, data2;
+  gpointer v_return;
+
+  g_return_if_fail (return_value != NULL);
+  g_return_if_fail (n_param_values == 2);
+
+  if (G_CCLOSURE_SWAP_DATA (closure))
+    {
+      data1 = closure->data;
+      data2 = g_value_peek_pointer (param_values + 0);
+    }
+  else
+    {
+      data1 = g_value_peek_pointer (param_values + 0);
+      data2 = closure->data;
+    }
+  callback = (GMarshalFunc_POINTER__POINTER) (marshal_data ? marshal_data : cc->callback);
+
+  v_return = callback (data1,
+                       g_marshal_value_peek_pointer (param_values + 1),
+                       data2);
+
+  g_value_set_pointer (return_value, v_return);
+}
+
