@@ -1,6 +1,6 @@
 /* gda-server-provider-extra.h
  *
- * Copyright (C) 2005 - 2007 Vivien Malerba
+ * Copyright (C) 2005 - 2008 Vivien Malerba
  *
  * This Library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Library General Public License as
@@ -27,6 +27,11 @@
 
 G_BEGIN_DECLS
 
+/*
+ * GdaSqlParser associated to each provider
+ */
+GdaSqlParser *gda_server_provider_internal_get_parser (GdaServerProvider *prov);
+
 /*
  * Help to implement providers, so the schemas return the same
  * number of columns and column titles across the providers.
@@ -35,6 +40,16 @@ gint      gda_server_provider_get_schema_nb_columns (GdaConnectionSchema schema)
 gboolean  gda_server_provider_init_schema_model     (GdaDataModel *model, GdaConnectionSchema schema);
 gboolean  gda_server_provider_test_schema_model     (GdaDataModel *model, GdaConnectionSchema schema, GError **error);
 
+/*
+ * Default perform operation
+ */
+gboolean gda_server_provider_perform_operation_default (GdaServerProvider *provider, GdaConnection *cnc,
+							GdaServerOperation *op, GError **error);
+
+/* default data handler method */
+GdaDataHandler *gda_server_provider_get_data_handler_default (GdaServerProvider *provider, GdaConnection *cnc,
+							      GType type, const gchar *dbms_type);
+
 
 /*
  * Help to implement the GdaDataHandler retreiving for the providers
@@ -45,11 +60,6 @@ typedef struct {
 	gchar         *dbms_type;
 } GdaServerProviderHandlerInfo;
 
-guint           gda_server_provider_handler_info_hash_func  (GdaServerProviderHandlerInfo *key);
-gboolean        gda_server_provider_handler_info_equal_func (GdaServerProviderHandlerInfo *a, 
-							     GdaServerProviderHandlerInfo *b);
-void            gda_server_provider_handler_info_free       (GdaServerProviderHandlerInfo *info);
-
 GdaDataHandler *gda_server_provider_handler_find            (GdaServerProvider *prov, GdaConnection *cnc, 
 							     GType g_type, const gchar *dbms_type);
 void            gda_server_provider_handler_declare         (GdaServerProvider *prov, GdaDataHandler *dh,
@@ -59,13 +69,13 @@ void            gda_server_provider_handler_declare         (GdaServerProvider *
 /*
  * misc
  */
-gboolean       gda_server_provider_blob_list_for_update     (GdaConnection *cnc, GdaQuery *query, 
-							     GdaQuery **out_select, GError **error);
-gboolean       gda_server_provider_blob_list_for_delete     (GdaConnection *cnc, GdaQuery *query, 
-							     GdaQuery **out_select, GError **error);
-gboolean       gda_server_provider_split_update_query       (GdaConnection *cnc, GdaQuery *query, 
-							     GdaQuery **out_query, GError **error);
-gboolean       gda_server_provider_select_query_has_blobs   (GdaConnection *cnc, GdaQuery *query, GError **error);
+gboolean       gda_server_provider_blob_list_for_update     (GdaConnection *cnc, GdaStatement *query, 
+							     GdaStatement **out_select, GError **error);
+gboolean       gda_server_provider_blob_list_for_delete     (GdaConnection *cnc, GdaStatement *query, 
+							     GdaStatement **out_stmt, GError **error);
+gboolean       gda_server_provider_split_update_query       (GdaConnection *cnc, GdaStatement *query, 
+							     GdaStatement **out_stmt, GError **error);
+gboolean       gda_server_provider_select_query_has_blobs   (GdaConnection *cnc, GdaStatement *stmt, GError **error);
 
 gchar         *gda_server_provider_find_file                (GdaServerProvider *prov, const gchar *inst_dir, const gchar *filename);
 gchar         *gda_server_provider_load_file_contents       (const gchar *inst_dir, const gchar *data_dir, const gchar *filename);
