@@ -1,5 +1,5 @@
 /* GDA common library
- * Copyright (C) 1998 - 2006 The GNOME Foundation.
+ * Copyright (C) 1998 - 2008 The GNOME Foundation.
  *
  * AUTHORS:
  *	Rodrigo Moya <rodrigo@gnome-db.org>
@@ -31,16 +31,16 @@
 #include <glib/gmessages.h>
 #include <glib/gstrfuncs.h>
 #include <glib/gprintf.h>
-#include <libsql/sql_parser.h>
 #include <glib/gi18n-lib.h>
 #include <libgda/gda-log.h>
 #include <libgda/gda-util.h>
 #include <libgda/gda-column.h>
-#include <libgda/gda-dict-field.h>
 #ifdef HAVE_LOCALE_H
 #include <locale.h>
 #endif
 
+#include <libgda/binreloc/gda-binreloc.h>
+
 /**
  * gda_g_type_to_string
  * @type: Type to convert from.
@@ -70,7 +70,15 @@ gda_g_type_from_string (const gchar *str)
 	
 	type = g_type_from_name (str);
 	if (type == 0) {
-		if (!strcmp (str, "null"))
+		if (!g_ascii_strcasecmp (str, "int"))
+			type = G_TYPE_INT;
+		else if (!g_ascii_strcasecmp (str, "string"))
+			type = G_TYPE_STRING;
+		else if (!g_ascii_strcasecmp (str, "date"))
+			type = G_TYPE_DATE;
+		else if (!strcmp (str, "boolean"))
+                        type = G_TYPE_BOOLEAN;
+		else if (!strcmp (str, "null"))
 			type = GDA_TYPE_NULL;
 		else
 			/* could not find a valid GType for @str */
@@ -85,7 +93,7 @@ gda_g_type_from_string (const gchar *str)
  * @string: string to escape
  *
  * Escapes @string to make it understandable by a DBMS. The escape method is very common and replaces any
- * occurence of "'" with "\'" and "\" with "\\".
+ * occurence of "'" with "''" and "\" with "\\"
  */
 gchar *
 gda_default_escape_string (const gchar *string)
@@ -111,7 +119,12 @@ gda_default_escape_string (const gchar *string)
 	ret = g_new0 (gchar, size);
 	retptr = ret;
 	while (*ptr) {
-		if ((*ptr == '\'') || (*ptr == '\\')) {
+		if (*ptr == '\'') {
+			*retptr = '\'';
+			*(retptr+1) = *ptr;
+			retptr += 2;
+		}
+		else if (*ptr == '\\') {
 			*retptr = '\\';
 			*(retptr+1) = *ptr;
 			retptr += 2;
@@ -277,34 +290,6 @@ gda_file_save (const gchar *filename, const gchar *buffer, gint len)
 	return res == -1 ? FALSE : TRUE;
 }
 
-/**
- * gda_utility_table_field_attrs_stringify
- */
-gchar *
-gda_utility_table_field_attrs_stringify (GdaValueAttribute attributes)
-{
-	if (attributes & FIELD_AUTO_INCREMENT)
-		return g_strdup ("AUTO_INCREMENT");
-
-	return NULL;
-}
-
-/**
- * gda_utility_table_field_attrs_parse
- */
-guint
-gda_utility_table_field_attrs_parse (const gchar *str)
-{
-	if (!str)
-		return 0;
-
-	if (!strcmp (str, "AUTO_INCREMENT"))
-		return FIELD_AUTO_INCREMENT;
-
-	return 0;
-}
-
-
 /**
  * gda_utility_build_encoded_id
  *
@@ -677,14 +662,17 @@ gda_utility_data_model_dump_data_to_xml (GdaDataModel *model, xmlNodePtr parent,
 		col_ids = g_new0 (gchar *, rnb_cols);
 		for (c = 0; c < rnb_cols; c++) {
 			GdaColumn *column;
-			const gchar *id;
+			gchar *id;
 		
 			column = gda_data_model_describe_column (model, rcols [c]);
 			g_object_get (G_OBJECT (column), "id", &id, NULL);
+
 			if (id && *id)
 				col_ids [c] = g_strdup (id);
 			else
 				col_ids [c] = g_strdup_printf ("_%d", c);
+
+			g_free(id);
 		}
 	}
 
@@ -747,15 +735,15 @@ gda_utility_data_model_dump_data_to_xml (GdaDataModel *model, xmlNodePtr parent,
 }
 
 /**
- * gda_utility_parameter_load_attributes
- * @param:
+ * gda_utility_holder_load_attributes
+ * @holder:
  * @node: an xmlNodePtr with a &lt;parameter&gt; tag
  * @sources: a list of #GdaDataModel
  *
  * WARNING: may set the "source" custom string property 
  */
 void
-gda_utility_parameter_load_attributes (GdaParameter *param, xmlNodePtr node, GSList *sources)
+gda_utility_holder_load_attributes (GdaHolder *holder, xmlNodePtr node, GSList *sources)
 {
 	xmlChar *str;
 	xmlNodePtr vnode;
@@ -763,36 +751,34 @@ gda_utility_parameter_load_attributes (GdaParameter *param, xmlNodePtr node, GSL
 	/* set properties from the XML spec */
 	str = xmlGetProp (node, BAD_CAST "id");
 	if (str) {
-		g_object_set (G_OBJECT (param), "string_id", (gchar*)str, NULL);
+		g_object_set (G_OBJECT (holder), "id", (gchar*)str, NULL);
 		xmlFree (str);
 	}	
 
 	str = xmlGetProp (node, BAD_CAST "name");
 	if (str) {
-		gda_object_set_name (GDA_OBJECT (param), (gchar*)str);
+		g_object_set (G_OBJECT (holder), "name", (gchar*)str, NULL);
 		xmlFree (str);
 	}
 	str = xmlGetProp (node, BAD_CAST "descr");
 	if (str) {
-		gda_object_set_description (GDA_OBJECT (param), (gchar*)str);
+		g_object_set (G_OBJECT (holder), "description", (gchar*)str, NULL);
 		xmlFree (str);
 	}
 	str = xmlGetProp (node, BAD_CAST "nullok");
 	if (str) {
-		gda_parameter_set_not_null (param, (*str == 'T') || (*str == 't') ? FALSE : TRUE);
+		gda_holder_set_not_null (holder, (*str == 'T') || (*str == 't') ? FALSE : TRUE);
 		xmlFree (str);
 	}
 	else
-		gda_parameter_set_not_null (param, FALSE);
+		gda_holder_set_not_null (holder, FALSE);
 	str = xmlGetProp (node, BAD_CAST "plugin");
-	if (str) {
-		g_object_set (G_OBJECT (param), "entry_plugin", (gchar*)str, NULL);
-		xmlFree (str);
-	}
+	if (str) 
+		g_object_set_data_full (G_OBJECT (holder), "__gda_entry_plugin", str, xmlFree);
 	
 	str = xmlGetProp (node, BAD_CAST "source");
 	if (str) 
-		g_object_set_data_full (G_OBJECT (param), "source", (gchar*)str, g_free);
+		g_object_set_data_full (G_OBJECT (holder), "source", (gchar*)str, g_free);
 
 	/* set restricting source if specified */
 	if (str && sources) {
@@ -808,7 +794,8 @@ gda_utility_parameter_load_attributes (GdaParameter *param, xmlNodePtr node, GSL
 			GSList *tmp = sources;
 			GdaDataModel *model = NULL;
 			while (tmp && !model) {
-				if (!strcmp (gda_object_get_name (GDA_OBJECT (tmp->data)), ptr1))
+				gchar *mname = g_object_get_data (G_OBJECT (tmp->data), "name");
+				if (mname && !strcmp (mname, ptr1))
 					model = GDA_DATA_MODEL (tmp->data);
 				tmp = g_slist_next (tmp);
 			}
@@ -821,14 +808,13 @@ gda_utility_parameter_load_attributes (GdaParameter *param, xmlNodePtr node, GSL
 				    (fno >= gda_data_model_get_n_columns (model))) 
 					g_warning (_("Field number %d not found in source named '%s'"), fno, ptr1); 
 				else {
-					if (gda_parameter_restrict_values (param, model, fno, NULL)) {
-						/* rename the wrapper with the current param's name */
-						g_object_set_data_full (G_OBJECT (model), "newname", 
-									g_strdup ((gchar *)gda_object_get_name (GDA_OBJECT (param))),
-									g_free);
-						g_object_set_data_full (G_OBJECT (model), "newdescr", 
-									g_strdup ((gchar *)gda_object_get_description (GDA_OBJECT (param))),
-									g_free);
+					if (gda_holder_set_source_model (holder, model, fno, NULL)) {
+						gchar *str;
+						/* rename the wrapper with the current holder's name */
+						g_object_get (G_OBJECT (holder), "name", &str, NULL);
+						g_object_set_data_full (G_OBJECT (model), "newname", str, g_free);
+						g_object_get (G_OBJECT (holder), "description", &str, NULL);
+						g_object_set_data_full (G_OBJECT (model), "newdescr", str, g_free);
 					}
 				}
 			}
@@ -842,7 +828,7 @@ gda_utility_parameter_load_attributes (GdaParameter *param, xmlNodePtr node, GSL
 		const gchar *lang;
 		GType gdatype;
 
-		gdatype = gda_parameter_get_g_type (param);
+		gdatype = gda_holder_get_g_type (holder);
 #ifdef HAVE_LC_MESSAGES
 		lang = setlocale (LC_MESSAGES, NULL);
 #else
@@ -877,19 +863,20 @@ gda_utility_parameter_load_attributes (GdaParameter *param, xmlNodePtr node, GSL
 			
 			if (!isnull) {
 				GValue *value;
+				gchar* nodeval = (gchar*)xmlNodeGetContent (vnode);
 
 				value = g_new0 (GValue, 1);
-				if (! gda_value_set_from_string (value, (gchar*)xmlNodeGetContent (vnode), gdatype)) {
+				if (! gda_value_set_from_string (value, nodeval, gdatype)) {
 					/* error */
 					g_free (value);
 				}
-				else {
-					gda_parameter_set_value (param, value);
-					gda_value_free (value);
-				}
+				else 
+					gda_holder_take_value (holder, value);
+
+ 				xmlFree(nodeval);
 			}
 			else {
-				gda_parameter_set_value (param, NULL);
+				gda_holder_set_value (holder, NULL);
 				xmlFree (isnull);
 			}
 			
@@ -898,58 +885,90 @@ gda_utility_parameter_load_attributes (GdaParameter *param, xmlNodePtr node, GSL
 	}
 }
 
+
+#define GDA_PARAM_ENCODE_TOKEN "__gda"
 /**
- * @dict:
- * @prov:
- * @cnc:
- * @dbms_type:
- * @g_type:
- * @created: a place to return if the data type has been created and is thus considered as a custom
- *           data type. Can't be %NULL!
+ * gda_text_to_alphanum
+ * @text:
  *
- * Finds or creates anew GdaDictType if possible. if @created is returned as TRUE, then the
- * caller of this function _does_ have a reference on the returned object.
+ * The "encoding" consists in replacing non
+ * alphanumeric character with the string "__gdaXX" where XX is the hex. representation
+ * of the non alphanumeric char.
  *
- * Returns: a #GdaDictType, or %NULL if it was not possible to find and create one
+ * Returns: a new string
  */
-GdaDictType *
-gda_utility_find_or_create_data_type (GdaDict *dict, GdaServerProvider *prov, GdaConnection *cnc, 
-				  const gchar *dbms_type, const gchar *g_type, gboolean *created)
+gchar *
+gda_text_to_alphanum (const gchar *text)
 {
-	GdaDictType *dtype = NULL;
+	GString *string;
+	const gchar* ptr = text;
+	gchar *ret;
 
-	g_return_val_if_fail (created, NULL);
-	g_return_val_if_fail (!dict || GDA_IS_DICT (dict), NULL);
-	g_return_val_if_fail (!prov || GDA_IS_SERVER_PROVIDER (prov), NULL);
-	g_return_val_if_fail (!cnc || GDA_IS_CONNECTION (cnc), NULL);
+	/*g_print ("%s (%s) ", __FUNCTION__, text);*/
+	string = g_string_new ("");
+	for (ptr = text; ptr && *ptr; ptr++) {
+		if (! (((*ptr >= '0') && (*ptr <= '9')) ||
+		       ((*ptr >= 'A') && (*ptr <= 'Z')) ||
+		       ((*ptr >= 'a') && (*ptr <= 'z')))) {
+			g_string_append (string, GDA_PARAM_ENCODE_TOKEN);
+			g_string_append_printf (string, "%0x", *ptr);
+		}
+		else
+			g_string_append_c (string, *ptr);
+	}
+	ret = string->str;
+	g_string_free (string, FALSE);
+	/*g_print ("=>#%s#\n", ret);*/
+	return ret;
+}
 
-	*created = FALSE;
-	if (dbms_type)
-		dtype = gda_dict_get_dict_type_by_name (ASSERT_DICT (dict), dbms_type);
+/**
+ * gda_alphanum_to_text
+ * @text:
+ *
+ * Does the opposite of gda_text_to_alphanum(), in the same string 
+ *
+ * Returns: @text if conversion succedded or %NULL if an error occurred
+ */
+gchar *
+gda_alphanum_to_text (gchar *text)
+{
+	gchar* ptr = text;
+	gint length = strlen (text);
+	static gint toklength = 0;
 
-	if (!dtype) {
-		if (g_type) {
-			GType gtype;
-			
-			gtype = gda_g_type_from_string (g_type);
-			if (prov) {
-				const gchar *deftype;
-				
-				deftype = gda_server_provider_get_default_dbms_type (prov, cnc, gtype);
-				if (deftype)
-					dtype = gda_dict_get_dict_type_by_name (ASSERT_DICT (dict), deftype);
-			}	
-			
-			if (!dtype) {
-				/* create a GdaDictType for that 'gda-type' */
-				dtype = GDA_DICT_TYPE (gda_dict_type_new (ASSERT_DICT (dict)));
-				gda_dict_type_set_sqlname (dtype, g_type);
-				gda_dict_type_set_g_type (dtype, gtype);
-				gda_dict_declare_object (ASSERT_DICT (dict), (GdaObject *) dtype);
-				*created = TRUE;
-			}
+	if (toklength == 0)
+		toklength = strlen (GDA_PARAM_ENCODE_TOKEN);
+	/*g_print ("%s (%s) ", __FUNCTION__, text);*/
+	for (ptr = text; ptr && *ptr; ) {
+		if ((length >= toklength + 2) && !strncmp (ptr, GDA_PARAM_ENCODE_TOKEN, toklength)) {
+			gchar *ptr2 = ptr + toklength;
+			char c = *ptr2;
+			gchar val;
+			if ((c >= 'a') && (c <= 'f'))
+				val = (c - 'a' + 10) * 16;
+			else if ((c >= '0') && (c <= '9'))
+				val = (c - '0') * 16;
+			else
+				return NULL;
+			c = *(ptr2+1);
+			if ((c >= 'a') && (c <= 'f'))
+				val += c - 'a' + 10;
+			else if ((c >= '0') && (c <= '9'))
+				val += c - '0';
+			else
+				return NULL;
+			*ptr = val;
+			ptr++;
+			length -= toklength + 1;
+			memmove (ptr, ptr + toklength + 1, length);
+		}
+		else {
+			ptr ++;
+			length --;
 		}
 	}
-
-	return dtype;
+	/*g_print ("=>#%s#\n", text);*/
+	return text;
 }
+
