@@ -16,7 +16,7 @@ main (int argc, char **argv)
 	gda_init ("check-providers", PACKAGE_VERSION, argc, argv);
 
 	setenv ("GDA_PROVIDERS_ROOT_DIR", GDA_PROVIDERS_ROOT_DIR, 0);
-	pinfo = gda_config_get_provider_by_name (PROVIDER);
+	pinfo = gda_config_get_provider_info (PROVIDER);
 	if (!pinfo) {
 		g_warning ("Could not find provider information for %s", PROVIDER);
 		return EXIT_FAILURE;
@@ -27,13 +27,15 @@ main (int argc, char **argv)
 
 	if (cnc) {
 		number_failed += prov_test_common_create_tables_sql ();
-		number_failed += prov_test_common_check_schemas ();
+		number_failed += prov_test_common_check_meta ();
 		number_failed += prov_test_common_clean ();
 	}
 
 	if (! params_provided)
 		return EXIT_SUCCESS;
-	else
+	else {
+		g_print ("Test %s\n", (number_failed == 0) ? "Ok" : "failed");
 		return (number_failed == 0) ? EXIT_SUCCESS : EXIT_FAILURE;
+	}
 }
 
